@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Literal
 
 from dateutil.parser import isoparse
 
-from ..core import BaseDomain
+from ..core import BaseDomain, DomainIdentityMixin
 
 if TYPE_CHECKING:
     from ..actions import BoundAction
@@ -22,7 +22,7 @@ if TYPE_CHECKING:
     from .client import BoundServer
 
 
-class Server(BaseDomain):
+class Server(BaseDomain, DomainIdentityMixin):
     """Server Domain
 
     :param id: int
@@ -81,7 +81,8 @@ class Server(BaseDomain):
     """Server Status rebuilding"""
     STATUS_UNKNOWN = "unknown"
     """Server Status unknown"""
-    __slots__ = (
+
+    __api_properties__ = (
         "id",
         "name",
         "status",
@@ -104,6 +105,7 @@ class Server(BaseDomain):
         "primary_disk_size",
         "placement_group",
     )
+    __slots__ = __api_properties__
 
     # pylint: disable=too-many-locals
     def __init__(
@@ -166,7 +168,8 @@ class CreateServerResponse(BaseDomain):
            The root password of the server if no SSH-Key was given on server creation
     """
 
-    __slots__ = ("server", "action", "next_actions", "root_password")
+    __api_properties__ = ("server", "action", "next_actions", "root_password")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -190,7 +193,8 @@ class ResetPasswordResponse(BaseDomain):
            The root password of the server
     """
 
-    __slots__ = ("action", "root_password")
+    __api_properties__ = ("action", "root_password")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -210,7 +214,8 @@ class EnableRescueResponse(BaseDomain):
            The root password of the server in the rescue mode
     """
 
-    __slots__ = ("action", "root_password")
+    __api_properties__ = ("action", "root_password")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -232,7 +237,8 @@ class RequestConsoleResponse(BaseDomain):
            VNC password to use for this connection. This password only works in combination with a wss_url with valid token.
     """
 
-    __slots__ = ("action", "wss_url", "password")
+    __api_properties__ = ("action", "wss_url", "password")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -252,7 +258,8 @@ class RebuildResponse(BaseDomain):
     :param root_password: The root password of the server when not using SSH keys
     """
 
-    __slots__ = ("action", "root_password")
+    __api_properties__ = ("action", "root_password")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -274,7 +281,7 @@ class PublicNetwork(BaseDomain):
     :param firewalls: List[:class:`PublicNetworkFirewall <hcloud.servers.client.PublicNetworkFirewall>`]
     """
 
-    __slots__ = (
+    __api_properties__ = (
         "ipv4",
         "ipv6",
         "floating_ips",
@@ -282,11 +289,12 @@ class PublicNetwork(BaseDomain):
         "primary_ipv4",
         "primary_ipv6",
     )
+    __slots__ = __api_properties__
 
     def __init__(
         self,
-        ipv4: IPv4Address,
-        ipv6: IPv6Network,
+        ipv4: IPv4Address | None,
+        ipv6: IPv6Network | None,
         floating_ips: list[BoundFloatingIP],
         primary_ipv4: BoundPrimaryIP | None,
         primary_ipv6: BoundPrimaryIP | None,
@@ -307,7 +315,8 @@ class PublicNetworkFirewall(BaseDomain):
     :param status: str
     """
 
-    __slots__ = ("firewall", "status")
+    __api_properties__ = ("firewall", "status")
+    __slots__ = __api_properties__
 
     STATUS_APPLIED = "applied"
     """Public Network Firewall Status applied"""
@@ -334,7 +343,8 @@ class IPv4Address(BaseDomain):
            DNS PTR for the ip
     """
 
-    __slots__ = ("ip", "blocked", "dns_ptr")
+    __api_properties__ = ("ip", "blocked", "dns_ptr")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -362,7 +372,8 @@ class IPv6Network(BaseDomain):
            The network mask
     """
 
-    __slots__ = ("ip", "blocked", "dns_ptr", "network", "network_mask")
+    __api_properties__ = ("ip", "blocked", "dns_ptr", "network", "network_mask")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -391,7 +402,8 @@ class PrivateNet(BaseDomain):
            The mac address of the interface on the server
     """
 
-    __slots__ = ("network", "ip", "alias_ips", "mac_address")
+    __api_properties__ = ("network", "ip", "alias_ips", "mac_address")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -415,7 +427,8 @@ class ServerCreatePublicNetwork(BaseDomain):
     :param enable_ipv6: bool
     """
 
-    __slots__ = ("ipv4", "ipv6", "enable_ipv4", "enable_ipv6")
+    __api_properties__ = ("ipv4", "ipv6", "enable_ipv4", "enable_ipv6")
+    __slots__ = __api_properties__
 
     def __init__(
         self,
@@ -443,7 +456,8 @@ class GetMetricsResponse(BaseDomain):
     :param metrics: The Server metrics
     """
 
-    __slots__ = ("metrics",)
+    __api_properties__ = ("metrics",)
+    __slots__ = __api_properties__
 
     def __init__(
         self,
